@@ -1,4 +1,4 @@
-package Pcore::Whois v0.3.1;
+package Pcore::Whois v0.3.2;
 
 use Pcore -class, -const;
 use Pcore::Util::Scalar qw[blessed];
@@ -12,8 +12,8 @@ has max_threads_server => ( is => 'lazy', isa => PositiveInt );
 has timeout            => ( is => 'ro',   isa => PositiveInt, default => 30 );
 has retries            => ( is => 'ro',   isa => PositiveInt, default => 3 );    # max. retries
 
-has ip_pool => ( is => 'ro', isa => InstanceOf ['Pcore::AE::Handle::IPPool'] );
-has proxy   => ( is => 'ro', isa => InstanceOf ['Pcore::AE::Handle::ProxyPool'] );
+has ip_pool => ( is => 'ro', isa => Maybe [ InstanceOf ['Pcore::AE::Handle::IPPool'] ] );
+has proxy   => ( is => 'ro', isa => Maybe [ InstanceOf ['Pcore::AE::Handle::ProxyPool'] ] );
 
 has cache         => ( is => 'ro', isa => Str );                                           # path to SQLite database
 has cache_timeout => ( is => 'ro', isa => PositiveOrZeroInt, default => 60 * 60 * 24 );    # 1 day, 0 - only put to the cache
